# -*- coding: utf-8 -*-
"""
    django-notifications-rest
    ~~~~~
   A django notifications package exposed by Rest.
"""

# PEP 386-compliant version number: N.N[.N]+[{a|b|c|rc}N[.N]+][.postN][.devN]
__version__ = "1.0.2"

default_app_config = "notifications_rest.apps.NotificationsRestConfig"
